@@ -80,6 +80,7 @@ ColorScheme::ColorScheme() : FileName()
     appendItem("RAGuideError", i18n("RA Guide Error"), "#00FF00");
     appendItem("DEGuideError", i18n("DEC Guide Error"), "#00A5FF");
     appendItem("SolverFOVColor", i18n("Solver FOV"), "#FFFFFF");
+    appendItem("SensorFOVColor", i18n("Sensor FOV"), "#FFAA00");
     appendItem("HIPSGridColor", i18n("HiPS Grid"), "#FFFFFF");
     appendItem("FITSObjectLabelColor", i18n("FITS Image Object Label"), "#00FF00");
 
@@ -199,12 +200,14 @@ bool ColorScheme::load(const QString &name)
     }
 
     // Dark Palette
+#if 0
     if (modes.count() > 2)
     {
         int newintens = modes[2].toInt(&ok);
         if (ok)
             setDarkPalette(newintens == 1);
     }
+#endif
 
     //More flexible method for reading in color values.  Any order is acceptable, and
     //missing entries are ignored.
@@ -343,7 +346,7 @@ void ColorScheme::loadFromConfig()
         setColor(KeyName.at(i), cg.readEntry(KeyName.at(i).toUtf8().constData(), Default.at(i)));
 
     setStarColorModeIntensity(cg.readEntry("StarColorMode", 0), cg.readEntry("StarColorIntensity", 5));
-    setDarkPalette(cg.readEntry("DarkAppColors", false));
+    //setDarkPalette(cg.readEntry("DarkAppColors", false));
 
     FileName = cg.readEntry("ColorSchemeFile", "moonless-night.colors");
 }
@@ -372,6 +375,7 @@ void ColorScheme::setStarColorMode(int mode)
 #endif
 }
 
+#if 0
 void ColorScheme::setDarkPalette(bool enable)
 {
     DarkPalette = enable ? 1 : 0;
@@ -380,6 +384,7 @@ void ColorScheme::setDarkPalette(bool enable)
     SkyQPainter::initStarImages();
 #endif
 }
+#endif
 
 void ColorScheme::setStarColorIntensity(int intens)
 {
