@@ -1,8 +1,19 @@
-/*
-    SPDX-FileCopyrightText: 2007 James B. Bowlin <bowlin@mindspring.com>
+/***************************************************************************
+                          ksfilereader.h  -  description
+                             -------------------
+    begin                : 2007-07-16
+    copyright            : (C) 2007 James B. Bowlin
+    email                : bowlin@mindspring.com
+ ***************************************************************************/
 
-    SPDX-License-Identifier: GPL-2.0-or-later
-*/
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 
 #pragma once
 
@@ -43,7 +54,7 @@ class QString;
  * way is to just instantiate KSFileReader with no parameters and then use the
  * open( QString fname ) method to let this class handle the file opening which
  * helps take unneeded complexity out of the calling classes.  I didn't make a
- * constructor with the filename in it because we need to be able to inform the
+ * contructor with the filename in it because we need to be able to inform the
  * caller of an error opening the file, hence the bool open(filename) method.
  *
  *
@@ -71,7 +82,7 @@ class KSFileReader : public QObject, public QTextStream
     explicit KSFileReader(QFile &file, qint64 maxLen = 1024);
 
     /**
-     * @short opens the file fname from the QStandardPaths::AppLocalDataLocation directory and uses that
+     * @short opens the file fname from the QStandardPaths::GenericDataLocation directory and uses that
      * file for the QTextStream.
      *
      * @param fname the name of the file to open
@@ -82,9 +93,9 @@ class KSFileReader : public QObject, public QTextStream
 
     /**
      * @short opens the file with full path fname and uses that
-     * file for the QTextStream. open() locates QStandardPaths::AppLocalDataLocation behind the scenes,
+     * file for the QTextStream. open() locates QStandardPaths::GenericDataLocation behind the scenes,
      * so passing fname such that
-     * QString fname = KSPaths::locate(QStandardPaths::AppLocalDataLocation, "file_name" );
+     * QString fname = KSPaths::locate(QStandardPaths::GenericDataLocation, "file_name" );
      * is equivalent
      *
      * @param fname full path to directory + name of the file to open
@@ -114,8 +125,7 @@ class KSFileReader : public QObject, public QTextStream
     /**
      * @short Prepares this instance to emit progress reports on how much
      * of the file has been read (in percent).
-     * @param label the label
-     * @param lastLine the number of lines to be read
+     * @param totalLines the number of lines to be read
      * @param numUpdates the number of progress reports to send
      */
     void setProgress(QString label, unsigned int lastLine, unsigned int numUpdates = 10);
