@@ -1250,7 +1250,7 @@ bool copyRecursively(QString sourceFolder, QString destFolder)
 
 QByteArray getJPLQueryString(const QByteArray &kind, const QByteArray &dataFields, const QVector<JPLFilter> &filters)
 {
-    QByteArray query("obj_group=all&obj_kind=" + kind + "&obj_numbered=num&OBJ_field=0&ORB_field=0");
+    QByteArray query("obj_group=all&obj_kind=" + kind + "&obj_numbered=all&OBJ_field=0&ORB_field=0");
 
     // Apply filters:
     for (int i = 0; i < filters.length(); i++)
@@ -1271,4 +1271,20 @@ QByteArray getJPLQueryString(const QByteArray &kind, const QByteArray &dataField
 
     return query;
 }
+
+QString formatSize(qint64 size)
+{
+    QStringList units = {"Bytes", "KB", "MB", "GB", "TB", "PB"};
+    int i=0;
+    double outputSize = size;
+
+    for(i=0; i<units.size()-1; i++)
+    {
+        if(outputSize<1024)
+            break;
+        outputSize = outputSize/1024;
+    }
+    return QString("%0 %1").arg(outputSize, 0, 'f', 2).arg(units[i]);
+}
+
 }
