@@ -1,33 +1,39 @@
-/*
-    SPDX-FileCopyrightText: 2001 Jason Harris <jharris@30doradus.org>
+/***************************************************************************
+                          finddialog.cpp  -  K Desktop Planetarium
+                             -------------------
+    begin                : Wed Jul 4 2001
+    copyright            : (C) 2001 by Jason Harris
+    email                : jharris@30doradus.org
+ ***************************************************************************/
 
-    SPDX-License-Identifier: GPL-2.0-or-later
-*/
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 
 #include "finddialog.h"
 
 #include "kstars.h"
 #include "kstarsdata.h"
-#include "ksnotification.h"
 #include "Options.h"
 #include "detaildialog.h"
-#include "skymap.h"
 #include "skyobjects/skyobject.h"
+#include "skyobjects/deepskyobject.h"
 #include "skycomponents/starcomponent.h"
+#include "skycomponents/syncedcatalogcomponent.h"
 #include "skycomponents/skymapcomposite.h"
 #include "tools/nameresolver.h"
 #include "skyobjectlistmodel.h"
-#include "catalogscomponent.h"
+
 #include <KMessageBox>
 
 #include <QSortFilterProxyModel>
 #include <QStringListModel>
 #include <QTimer>
-#include <QComboBox>
-#include <QLineEdit>
-#include <QPointer>
-
-FindDialog *FindDialog::m_Instance = nullptr;
 
 FindDialogUI::FindDialogUI(QWidget *parent) : QFrame(parent)
 {
@@ -51,27 +57,14 @@ FindDialogUI::FindDialogUI(QWidget *parent) : QFrame(parent)
     SearchList->setMinimumHeight(320);
 }
 
-FindDialog *FindDialog::Instance()
-{
-    if (m_Instance == nullptr)
-        m_Instance = new FindDialog(KStars::Instance());
-
-    return m_Instance;
-}
-
-FindDialog::FindDialog(QWidget *parent)
-    : QDialog(parent)
-    , timer(nullptr)
-    , m_targetObject(nullptr)
-    , m_asyncDBManager(new CatalogsDB::AsyncDBManager(CatalogsDB::dso_db_path()))
-    , m_dbManager(CatalogsDB::dso_db_path())
+FindDialog::FindDialog(QWidget *parent) : QDialog(parent), timer(nullptr), m_targetObject(nullptr)
 {
 #ifdef Q_OS_OSX
     setWindowFlags(Qt::Tool | Qt::WindowStaysOnTopHint);
 #endif
     ui = new FindDialogUI(this);
 
-    setWindowTitle(i18nc("@title:window", "Find Object"));
+    setWindowTitle(i18n("Find Object"));
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
     mainLayout->addWidget(ui);
@@ -83,7 +76,6 @@ FindDialog::FindDialog(QWidget *parent)
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
     okB = buttonBox->button(QDialogButtonBox::Ok);
-    okB->setEnabled(false);
 
     QPushButton *detailB = new QPushButton(i18n("Details..."));
     buttonBox->addButton(detailB, QDialogButtonBox::ActionRole);
@@ -95,8 +87,7 @@ FindDialog::FindDialog(QWidget *parent)
 
     ui->FilterType->setCurrentIndex(0); // show all types of objects
 
-    fModel = new SkyObjectListModel(this);
-    connect(KStars::Instance()->map(), &SkyMap::removeSkyObject, fModel, &SkyObjectListModel::removeSkyObject);
+    fModel    = new SkyObjectListModel(this);
     sortModel = new QSortFilterProxyModel(ui->SearchList);
     sortModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     sortModel->setSourceModel(fModel);
@@ -108,37 +99,10 @@ FindDialog::FindDialog(QWidget *parent)
     ui->SearchList->setModel(sortModel);
 
     // Connect signals to slots
-    connect(ui->clearHistoryB, &QPushButton::clicked, [&]()
-    {
-        ui->clearHistoryB->setEnabled(false);
-        m_HistoryCombo->clear();
-        m_HistoryList.clear();
-    });
-
-    m_HistoryCombo = new QComboBox(ui->showHistoryB);
-    m_HistoryCombo->move(0, ui->showHistoryB->height());
-    connect(ui->showHistoryB, &QPushButton::clicked, [&]()
-    {
-        if (m_HistoryList.empty() == false)
-        {
-            m_HistoryCombo->showPopup();
-        }
-    });
-
-    connect(m_HistoryCombo, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
-            [&](int index)
-    {
-        m_targetObject = m_HistoryList[index];
-        m_targetObject->updateCoordsNow(KStarsData::Instance()->updateNum());
-        m_HistoryCombo->setCurrentIndex(-1);
-        m_HistoryCombo->hidePopup();
-        accept();
-    });
-    connect(ui->SearchBox, &QLineEdit::textChanged, this, &FindDialog::enqueueSearch);
-    connect(ui->SearchBox, &QLineEdit::returnPressed, this, &FindDialog::slotOk);
-    connect(ui->FilterType, &QComboBox::currentTextChanged, this, &FindDialog::enqueueSearch);
+    connect(ui->SearchBox, SIGNAL(textChanged(QString)), SLOT(enqueueSearch()));
+    connect(ui->SearchBox, SIGNAL(returnPressed()), SLOT(slotOk()));
+    connect(ui->FilterType, SIGNAL(activated(int)), this, SLOT(enqueueSearch()));
     connect(ui->SearchList, SIGNAL(doubleClicked(QModelIndex)), SLOT(slotOk()));
-    connect(ui->SearchList->selectionModel(), &QItemSelectionModel::selectionChanged, this, &FindDialog::slotUpdateButtons);
 
     // Set focus to object name edit
     ui->SearchBox->setFocus();
@@ -149,14 +113,12 @@ FindDialog::FindDialog(QWidget *parent)
     listFiltered = false;
 }
 
+FindDialog::~FindDialog()
+{
+}
+
 void FindDialog::init()
 {
-    const auto &objs = m_dbManager.get_objects(Options::magLimitDrawDeepSky(), 100);
-    for (const auto &obj : objs)
-    {
-        KStarsData::Instance()->skyComposite()->catalogsComponent()->insertStaticObject(
-            obj);
-    }
     ui->SearchBox->clear();
     filterByType();
     sortModel->sort(0);
@@ -164,12 +126,6 @@ void FindDialog::init()
     m_targetObject = nullptr;
 }
 
-void FindDialog::showEvent(QShowEvent *e)
-{
-    ui->SearchBox->setFocus();
-    e->accept();
-}
-
 void FindDialog::initSelection()
 {
     if (sortModel->rowCount() <= 0)
@@ -178,9 +134,6 @@ void FindDialog::initSelection()
         return;
     }
 
-    //    ui->SearchBox->setModel(sortModel);
-    //    ui->SearchBox->setModelColumn(0);
-
     if (ui->SearchBox->text().isEmpty())
     {
         //Pre-select the first item
@@ -219,6 +172,8 @@ void FindDialog::initSelection()
             ui->SearchList->selectionModel()->select(selectItem, QItemSelectionModel::ClearAndSelect);
             ui->SearchList->scrollTo(selectItem);
             ui->SearchList->setCurrentIndex(selectItem);
+
+            okB->setEnabled(true);
         }
     }
 
@@ -296,43 +251,15 @@ void FindDialog::filterByType()
 void FindDialog::filterList()
 {
     QString SearchText = processSearchText();
-    //const std::size_t searchId = m_currentSearchSequence;
-
-    // JM 2022.08.28: Disabling use of async DB manager until further notice since it appears to cause a crash
-    // on MacOS and some embedded systems.
-    //    QEventLoop loop;
-    //    QMutexLocker {&dbCallMutex}; // To prevent re-entrant calls into this
-    //    connect(m_asyncDBManager.get(), &CatalogsDB::AsyncDBManager::resultReady, &loop, &QEventLoop::quit);
-    //    QMetaObject::invokeMethod(m_asyncDBManager.get(), [&](){
-    //        m_asyncDBManager->find_objects_by_name(SearchText, 10); });
-    //    loop.exec();
-    //    std::unique_ptr<CatalogsDB::CatalogObjectList> objs = m_asyncDBManager->result();
-    //    if (m_currentSearchSequence != searchId) {
-    //        return; // Ignore this search since the search text has changed
-    //    }
-
-    auto objs = m_dbManager.find_objects_by_name(SearchText, 10);
-
-    bool exactMatchExists = objs.size() > 0 ? QString::compare(objs.front().name(), SearchText, Qt::CaseInsensitive) : false;
-
-    for (const auto &obj : objs)
-    {
-        KStarsData::Instance()->skyComposite()->catalogsComponent()->insertStaticObject(
-            obj);
-    }
-
     sortModel->setFilterFixedString(SearchText);
-    ui->InternetSearchButton->setText(i18n("Search the Internet for %1", SearchText.isEmpty() ? i18nc("no text to search for",
-                                           "(nothing)") : SearchText));
+    ui->InternetSearchButton->setText(i18n("or search the internet for %1", SearchText));
     filterByType();
     initSelection();
 
-    bool enableInternetSearch = (!exactMatchExists) && (ui->FilterType->currentIndex() == 0);
     //Select the first item in the list that begins with the filter string
     if (!SearchText.isEmpty())
     {
-        QStringList mItems =
-            fModel->filter(QRegExp('^' + SearchText, Qt::CaseInsensitive));
+        QStringList mItems = fModel->filter(QRegExp('^' + SearchText, Qt::CaseInsensitive));
         mItems.sort();
 
         if (mItems.size())
@@ -342,34 +269,20 @@ void FindDialog::filterList()
 
             if (selectItem.isValid())
             {
-                ui->SearchList->selectionModel()->select(
-                    selectItem, QItemSelectionModel::ClearAndSelect);
+                ui->SearchList->selectionModel()->select(selectItem, QItemSelectionModel::ClearAndSelect);
                 ui->SearchList->scrollTo(selectItem);
                 ui->SearchList->setCurrentIndex(selectItem);
+
+                okB->setEnabled(true);
             }
         }
-        ui->InternetSearchButton->setEnabled(enableInternetSearch && !mItems.contains(
-                SearchText, Qt::CaseInsensitive)); // Disable searching the internet when an exact match for SearchText exists in KStars
+        ui->InternetSearchButton->setEnabled(!mItems.contains(
+            SearchText)); // Disable searching the internet when an exact match for SearchText exists in KStars
     }
     else
         ui->InternetSearchButton->setEnabled(false);
 
     listFiltered = true;
-    slotUpdateButtons();
-}
-
-void FindDialog::slotUpdateButtons()
-{
-    okB->setEnabled(ui->SearchList->selectionModel()->hasSelection());
-
-    if (okB->isEnabled())
-    {
-        okB->setDefault(true);
-    }
-    else if (ui->InternetSearchButton->isEnabled())
-    {
-        ui->InternetSearchButton->setDefault(true);
-    }
 }
 
 SkyObject *FindDialog::selectedObject() const
@@ -391,69 +304,48 @@ void FindDialog::enqueueSearch()
     {
         timer = new QTimer(this);
         timer->setSingleShot(true);
-        connect(timer, &QTimer::timeout, [&]()
-        {
-            this->m_currentSearchSequence++;
-            this->filterList();
-        });
+        connect(timer, SIGNAL(timeout()), this, SLOT(filterList()));
     }
     timer->start(500);
 }
 
 // Process the search box text to replace equivalent names like "m93" with "m 93"
-QString FindDialog::processSearchText(QString searchText)
+QString FindDialog::processSearchText()
 {
     QRegExp re;
-    re.setCaseSensitivity(Qt::CaseInsensitive);
+    QString searchtext = ui->SearchBox->text();
 
-    // Remove multiple spaces and replace them by a single space
-    re.setPattern("  +");
-    searchText.replace(re, " ");
+    re.setCaseSensitivity(Qt::CaseInsensitive);
 
     // If it is an NGC/IC/M catalog number, as in "M 76" or "NGC 5139", check for absence of the space
     re.setPattern("^(m|ngc|ic)\\s*\\d*$");
-    if (searchText.contains(re))
+    if (ui->SearchBox->text().contains(re))
     {
         re.setPattern("\\s*(\\d+)");
-        searchText.replace(re, " \\1");
+        searchtext.replace(re, " \\1");
         re.setPattern("\\s*$");
-        searchText.remove(re);
+        searchtext.remove(re);
         re.setPattern("^\\s*");
-        searchText.remove(re);
-    }
-
-    // If it is a comet, and starts with c20## or c 20## make it c/20## (or similar with p).
-    re.setPattern("^(c|p)\\s*((19|20).*)");
-    if (searchText.contains(re))
-    {
-        if (searchText.at(0) == 'c' || searchText.at(0) == 'C')
-            searchText.replace(re, "c/\\2");
-        else searchText.replace(re, "p/\\2");
+        searchtext.remove(re);
     }
 
     // TODO after KDE 4.1 release:
     // If it is a IAU standard three letter abbreviation for a constellation, then go to that constellation
     // Check for genetive names of stars. Example: alp CMa must go to alpha Canis Majoris
 
-    return searchText;
+    return searchtext;
 }
 
 void FindDialog::slotOk()
 {
-    // JM 2022.04.20 Below does not work when a user is simply browsing
-    // and selecting an item without entering any text in the search box.
     //If no valid object selected, show a sorry-box.  Otherwise, emit accept()
-    //    if (ui->SearchBox->text().isEmpty())
-    //    {
-    //        return;
-    //    }
     SkyObject *selObj;
     if (!listFiltered)
     {
         filterList();
     }
     selObj = selectedObject();
-    finishProcessing(selObj, Options::resolveNamesOnline() && ui->InternetSearchButton->isEnabled());
+    finishProcessing(selObj, Options::resolveNamesOnline());
 }
 
 void FindDialog::slotResolve()
@@ -461,84 +353,30 @@ void FindDialog::slotResolve()
     finishProcessing(nullptr, true);
 }
 
-CatalogObject *FindDialog::resolveAndAdd(CatalogsDB::DBManager &db_manager, const QString &query)
-{
-    CatalogObject *dso = nullptr;
-    const auto &cedata = NameResolver::resolveName(query);
-
-    if (cedata.first)
-    {
-        db_manager.add_object(CatalogsDB::user_catalog_id, cedata.second);
-        const auto &added_object =
-            db_manager.get_object(cedata.second.getId(), CatalogsDB::user_catalog_id);
-
-        if (added_object.first)
-        {
-            dso = &KStarsData::Instance()
-                  ->skyComposite()
-                  ->catalogsComponent()
-                  ->insertStaticObject(added_object.second);
-        }
-    }
-    return dso;
-}
-
 void FindDialog::finishProcessing(SkyObject *selObj, bool resolve)
 {
     if (!selObj && resolve)
     {
-        selObj = resolveAndAdd(m_dbManager, processSearchText());
+        CatalogEntryData cedata;
+        cedata             = NameResolver::resolveName(processSearchText());
+        DeepSkyObject *dso = nullptr;
+        if (!std::isnan(cedata.ra) && !std::isnan(cedata.dec))
+        {
+            dso = KStarsData::Instance()->skyComposite()->internetResolvedComponent()->addObject(cedata);
+            if (dso)
+                qDebug() << dso->ra0().toHMSString() << ";" << dso->dec0().toDMSString();
+            selObj = dso;
+        }
     }
     m_targetObject = selObj;
     if (selObj == nullptr)
     {
         QString message = i18n("No object named %1 found.", ui->SearchBox->text());
-        KSNotification::sorry(message, i18n("Bad object name"));
+        KMessageBox::sorry(nullptr, message, i18n("Bad object name"));
     }
     else
     {
         selObj->updateCoordsNow(KStarsData::Instance()->updateNum());
-        if (m_HistoryList.contains(selObj) == false)
-        {
-            switch (selObj->type())
-            {
-                case SkyObject::OPEN_CLUSTER:
-                case SkyObject::GLOBULAR_CLUSTER:
-                case SkyObject::GASEOUS_NEBULA:
-                case SkyObject::PLANETARY_NEBULA:
-                case SkyObject::SUPERNOVA_REMNANT:
-                case SkyObject::GALAXY:
-                    if (selObj->name() != selObj->longname())
-                        m_HistoryCombo->addItem(QString("%1 (%2)")
-                                                .arg(selObj->name())
-                                                .arg(selObj->longname()));
-                    else
-                        m_HistoryCombo->addItem(QString("%1").arg(selObj->longname()));
-                    break;
-
-                case SkyObject::STAR:
-                case SkyObject::CATALOG_STAR:
-                case SkyObject::PLANET:
-                case SkyObject::COMET:
-                case SkyObject::ASTEROID:
-                case SkyObject::CONSTELLATION:
-                case SkyObject::MOON:
-                case SkyObject::ASTERISM:
-                case SkyObject::GALAXY_CLUSTER:
-                case SkyObject::DARK_NEBULA:
-                case SkyObject::QUASAR:
-                case SkyObject::MULT_STAR:
-                case SkyObject::RADIO_SOURCE:
-                case SkyObject::SATELLITE:
-                case SkyObject::SUPERNOVA:
-                default:
-                    m_HistoryCombo->addItem(QString("%1").arg(selObj->longname()));
-                    break;
-            }
-
-            m_HistoryList.append(selObj);
-        }
-        ui->clearHistoryB->setEnabled(true);
         accept();
     }
 }
@@ -577,29 +415,8 @@ void FindDialog::slotDetails()
     if (selectedObject())
     {
         QPointer<DetailDialog> dd = new DetailDialog(selectedObject(), KStarsData::Instance()->ut(),
-                KStarsData::Instance()->geo(), KStars::Instance());
+                                                     KStarsData::Instance()->geo(), KStars::Instance());
         dd->exec();
         delete dd;
     }
 }
-
-int FindDialog::execWithParent(QWidget* parent)
-{
-    QWidget * const oldParent = parentWidget();
-
-    if (nullptr != parent)
-    {
-        setParent(parent);
-        setWindowFlag(Qt::Dialog, true);
-    }
-
-    int const result = QDialog::exec();
-
-    if (nullptr != parent)
-    {
-        setParent(oldParent);
-        setWindowFlag(Qt::Dialog, true);
-    }
-
-    return result;
-}
