@@ -511,7 +511,6 @@ class Capture : public QWidget, public Ui::Capture
     void newStatus(Ekos::CaptureState status);
     void newImage(QImage *image, Ekos::SequenceJob *job);
     void newExposureProgress(Ekos::SequenceJob *job);
-    void newFocusOffset(int16_t offset);
 
   private:
     void setBusy(bool enable);
@@ -532,7 +531,8 @@ class Capture : public QWidget, public Ui::Capture
 
     // DSLR Info
     void addDSLRInfo(const QString &model, uint32_t maxW, uint32_t maxH, double pixelW, double pixelH);
-    void cullToCameraLimits();
+    void cullToDSLRLimits();
+    //void syncDriverToDSLRLimits();
     bool isModelinDSLRInfo(const QString &model);
 
     /* Meridian Flip */
