@@ -33,6 +33,7 @@ static const QStringList guideStates = { I18N_NOOP("Idle"),
                                          I18N_NOOP("Calibrated"),
                                          I18N_NOOP("Guiding"),
                                          I18N_NOOP("Suspended"),
+                                         I18N_NOOP("Reacquiring"),
                                          I18N_NOOP("Dithering"),
                                          I18N_NOOP("Dithering error"),
                                          I18N_NOOP("Dithering successful"),
@@ -53,6 +54,7 @@ typedef enum {
     GUIDE_CALIBRATION_SUCESS,
     GUIDE_GUIDING,
     GUIDE_SUSPENDED,
+    GUIDE_REACQUIRE,
     GUIDE_DITHERING,
     GUIDE_DITHERING_ERROR,
     GUIDE_DITHERING_SUCCESS,
