@@ -56,7 +56,7 @@ ProfileEditor::ProfileEditor(QWidget *w) : QDialog(w)
 
     connect(ui->guideTypeCombo, SIGNAL(activated(int)), this, SLOT(updateGuiderSelection(int)));
 
-    ui->addScopeB->setIcon(QIcon::fromTheme("list-add", QIcon(":/icons/breeze/default/list-add.svg")));
+    ui->addScopeB->setIcon(QIcon::fromTheme("list-add"));
     connect(ui->addScopeB, &QPushButton::clicked, this, [this]()
     {
         QPointer<EquipmentWriter> equipmentdlg = new EquipmentWriter();
@@ -538,7 +538,7 @@ void ProfileEditor::loadDrivers()
         box->setMaxVisibleItems(20);
     }
 
-    QIcon remoteIcon = QIcon::fromTheme("modem", QIcon(":/icons/breeze/default/modem.svg"));
+    QIcon remoteIcon = QIcon::fromTheme("modem");
 
     foreach (DriverInfo *dv, DriverManager::Instance()->getDrivers())
     {
