@@ -12,6 +12,7 @@
 #include "skypoint.h"
 
 #include <QUrl>
+#include <QMap>
 
 class QTableWidgetItem;
 
@@ -144,7 +145,10 @@ class SchedulerJob
     uint16_t getRepeatsRemaining() const;
     void setRepeatsRemaining(const uint16_t &value);
 
-  private:
+    QMap<QString, uint16_t> getCapturedFramesMap() const;
+    void setCapturedFramesMap(const QMap<QString, uint16_t> &value);
+
+private:
     QString name;
     SkyPoint targetCoords;
     JOBStatus state { JOB_IDLE };
@@ -183,4 +187,6 @@ class SchedulerJob
     QString dateTimeDisplayFormat;
 
     bool lightFramesRequired { false };
+
+    QMap<QString, uint16_t> capturedFramesMap;
 };
