@@ -63,17 +63,17 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QHBoxLayout *topLayout = new QHBoxLayout();
-    QHBoxLayout *bottomLayout = new QHBoxLayout();
+    QHBoxLayout *controlsLayout = new QHBoxLayout();
     QWidget* rightWidget = new QWidget();
     rightWidget->setVisible(false);
     QVBoxLayout *rightLayout = new QVBoxLayout(rightWidget);
-    QHBoxLayout *sliderLayout = new QHBoxLayout();
+    QGridLayout *sliderLayout = new QGridLayout();
 
     topLayout->addWidget(container, 1);
     topLayout->addWidget(rightWidget);
     mainLayout->addLayout(topLayout);
-    mainLayout->addLayout(bottomLayout);
-    bottomLayout->setAlignment(Qt::AlignLeft);
+    mainLayout->addLayout(controlsLayout);
+    controlsLayout->setAlignment(Qt::AlignLeft);
 
     maxValue=new QLabel(this);
     maxValue->setToolTip("Maximum Value on the graph");
@@ -87,15 +87,18 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
 
     blackPointSlider=new QSlider( Qt::Vertical, this);
     blackPointSlider->setToolTip("Sets the Minimum Value on the graph");
-    sliderLayout->addWidget(blackPointSlider);
+    sliderLayout->addWidget(blackPointSlider,0,0);
+    sliderLayout->addWidget(new QLabel("Min"),1,0);
 
     whitePointSlider=new QSlider( Qt::Vertical, this);
     whitePointSlider->setToolTip("Sets the Maximum Value on the graph");
-    sliderLayout->addWidget(whitePointSlider);
+    sliderLayout->addWidget(whitePointSlider,0,1);
+    sliderLayout->addWidget(new QLabel("Max"),1,1);
 
     cutoffSlider=new QSlider( Qt::Vertical, this);
     cutoffSlider->setToolTip("Sets the Cuttoff Maximum for eliminating hot pixels and bright stars.");
-    sliderLayout->addWidget(cutoffSlider);
+    sliderLayout->addWidget(cutoffSlider,0,2);
+    sliderLayout->addWidget(new QLabel("Cut"),1,2);
     cutoffSlider->setEnabled(false);
 
     minValue = new QLabel(this);
@@ -106,8 +109,11 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
     autoScale->setToolTip("Automatically scales the sliders for the subFrame.\nUncheck to leave them unchanged when you pan around.");
     autoScale->setChecked(true);
 
-    showScaling = new QCheckBox(this);
-    showScaling->setText("Scaling");
+    showScaling = new QPushButton(this);
+    showScaling->setIcon(QIcon::fromTheme("transform-move-vertical"));
+    showScaling->setCheckable(true);
+    showScaling->setMaximumSize(22, 22);
+    showScaling->setAttribute(Qt::WA_LayoutUsesWidgetRect);
     showScaling->setToolTip("Hides and shows the scaling side panel");
     showScaling->setChecked(false);
 
@@ -115,7 +121,6 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
     rightLayout->addWidget(cutoffValue);
     rightLayout->addWidget(maxValue);
     rightLayout->addLayout(sliderLayout);
-    rightLayout->addWidget(new QLabel("Min, Max, Cut     "));
     rightLayout->addWidget(minValue);
     rightLayout->addWidget(autoScale);
 
@@ -127,24 +132,41 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
     selectionType->setCurrentIndex(0);
 
     sliceB = new QPushButton(this);
-    sliceB->setText(QStringLiteral("Slice"));
+    sliceB->setIcon(QIcon::fromTheme("view-object-histogram-linear"));
+    sliceB->setCheckable(true);
+    sliceB->setMaximumSize(22, 22);
+    sliceB->setAttribute(Qt::WA_LayoutUsesWidgetRect);
     sliceB->setToolTip("Toggles the slice view when horizontal or vertical items are selected");
     sliceB->setCheckable(true);
     sliceB->setChecked(false);
     sliceB->setEnabled(false);
     sliceB->setDefault(false);
 
-    HFRReport = new QCheckBox(this);
-    HFRReport->setToolTip("Shows the HFR of stars in the frame");
-    HFRReport->setText("HFR: ");
-    HFRReport->setChecked(true);
-    HFRReportBox = new QLabel(this);
+    showCoordinates = new QPushButton(this);
+    showCoordinates->setIcon(QIcon::fromTheme("coordinate"));
+    showCoordinates->setCheckable(true);
+    showCoordinates->setMaximumSize(22, 22);
+    showCoordinates->setAttribute(Qt::WA_LayoutUsesWidgetRect);
+    showCoordinates->setToolTip("Shows the x, y coordinates of star centers in the frame");
+    showCoordinates->setChecked(false);
 
-    showPeakValues = new QCheckBox(this);
-    showPeakValues->setText("Peak: ");
-    showPeakValues->setToolTip("Shows the peak values of stars in the frame");
+    HFRReport = new QPushButton(this);
+    HFRReport->setToolTip("Shows the HFR of stars in the frame");
+    HFRReport->setIcon(QIcon::fromTheme("tool-measure"));
+    HFRReport->setCheckable(true);
+    HFRReport->setMaximumSize(22, 22);
+    HFRReport->setAttribute(Qt::WA_LayoutUsesWidgetRect);
+    HFRReport->setChecked(true);
+
+    reportBox = new QLabel(this);
+
+    showPeakValues = new QPushButton(this);
+    showPeakValues->setIcon(QIcon::fromTheme("kruler-east"));
+    showPeakValues->setCheckable(true);
+    showPeakValues->setMaximumSize(22, 22);
+    showPeakValues->setAttribute(Qt::WA_LayoutUsesWidgetRect);
+    showPeakValues->setToolTip("Shows the peak values of star centers in the frame");
     showPeakValues->setChecked(true);
-    peakValue = new QLabel(this);
 
     sampleSize = new QComboBox(this);
     sampleSize->setToolTip("Changes the sample size shown in the graph");
@@ -157,6 +179,75 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
     sampleSize->setCurrentIndex(3);
     sampleSize->setVisible(false);
 
+    zoomView = new QComboBox(this);
+    zoomView->setToolTip("Zooms the view to preset locations.");
+    zoomView->addItem(QStringLiteral("ZoomTo:"));
+    zoomView->addItem(QStringLiteral("Front"));
+    zoomView->addItem(QStringLiteral("Front High"));
+    zoomView->addItem(QStringLiteral("Overhead"));
+    zoomView->addItem(QStringLiteral("Iso. L"));
+    zoomView->addItem(QStringLiteral("Iso. R"));
+    zoomView->addItem(QStringLiteral("Selected"));
+    zoomView->setCurrentIndex(0);
+
+    QPushButton *selectorsVisible = new QPushButton(this);
+    selectorsVisible->setIcon(QIcon::fromTheme("adjustlevels"));
+    selectorsVisible->setCheckable(true);
+    selectorsVisible->setMaximumSize(22, 22);
+    selectorsVisible->setAttribute(Qt::WA_LayoutUsesWidgetRect);
+    selectorsVisible->setToolTip("Hides and shows the Vertical and Horizontal Selection Sliders");
+    selectorsVisible->setChecked(false);
+
+    controlsLayout->addWidget(sampleSize);
+    controlsLayout->addWidget(selectionType);
+    controlsLayout->addWidget(selectorsVisible);
+    controlsLayout->addWidget(sliceB);
+    controlsLayout->addWidget(showScaling);
+    //bottomLayout->addWidget(barSpacing);
+    controlsLayout->addWidget(zoomView);
+    //bottomLayout->addWidget(color);
+    controlsLayout->addWidget(showCoordinates);
+    controlsLayout->addWidget(HFRReport);
+    controlsLayout->addWidget(showPeakValues);
+    controlsLayout->addWidget(reportBox);
+
+    QWidget *bottomSliderWidget= new QWidget(this);
+    QGridLayout *bottomSliders = new QGridLayout(bottomSliderWidget);
+    bottomSliderWidget->setLayout(bottomSliders);
+    mainLayout->addWidget(bottomSliderWidget);
+    bottomSliderWidget->setVisible(false);
+
+    verticalSelector = new QSlider(Qt::Horizontal, this);
+    verticalSelector->setToolTip("Selects the Vertical Value");
+    horizontalSelector = new QSlider(Qt::Horizontal, this);
+    horizontalSelector->setToolTip("Selects the Horizontal Value");
+
+    bottomSliders->addWidget(new QLabel("Vertical: "), 0, 0);
+    bottomSliders->addWidget(verticalSelector, 0, 1);
+    bottomSliders->addWidget(new QLabel("Horizontal: "), 1, 0);
+    bottomSliders->addWidget(horizontalSelector, 1, 1);
+
+    QWidget *bottomControlsWidget= new QWidget(this);
+    QHBoxLayout *bottomControlLayout = new QHBoxLayout(bottomControlsWidget);
+    mainLayout->addWidget(bottomControlsWidget);\
+    bottomControlsWidget->setVisible(false);
+
+    exploreMode = new QPushButton(this);
+    exploreMode->setIcon(QIcon::fromTheme("visibility"));
+    exploreMode->setCheckable(true);
+    exploreMode->setMaximumSize(22, 22);
+    exploreMode->setAttribute(Qt::WA_LayoutUsesWidgetRect);
+    exploreMode->setToolTip("Zooms automatically as the sliders change");
+    exploreMode->setChecked(true);
+
+    QDial *barSpacing=new QDial(this);
+    barSpacing->setMinimum(0);
+    barSpacing->setMaximum(100);
+    barSpacing->setValue(50);
+    barSpacing->setMaximumSize(32, 32);
+    barSpacing->setWrapping(false);
+    m_graph->setBarSpacing(QSizeF(0.5,0.5));
+
     QComboBox *color = new QComboBox(this);
     color->setToolTip("Changes the color scheme");
 
@@ -187,48 +278,12 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
     color->setCurrentIndex(0);
     color->setMaximumWidth(80);
 
-    zoomView = new QComboBox(this);
-    zoomView->setToolTip("Zooms the view to preset locations.");
-    zoomView->addItem(QStringLiteral("ZoomTo:"));
-    zoomView->addItem(QStringLiteral("Front"));
-    zoomView->addItem(QStringLiteral("Front High"));
-    zoomView->addItem(QStringLiteral("Overhead"));
-    zoomView->addItem(QStringLiteral("Isometric L"));
-    zoomView->addItem(QStringLiteral("Isometric R"));
-    zoomView->addItem(QStringLiteral("Selected Item"));
-    zoomView->setCurrentIndex(0);
+    pixelReport = new QLabel("", bottomControlsWidget);
 
-    QCheckBox *selectorsVisible = new QCheckBox(this);
-    selectorsVisible->setToolTip("Hides and shows the Vertical and Horizontal Selection Sliders");
-    selectorsVisible->setChecked(false);
-
-    bottomLayout->addWidget(sampleSize);
-    bottomLayout->addWidget(selectionType);
-    bottomLayout->addWidget(selectorsVisible);
-    bottomLayout->addWidget(sliceB);
-    bottomLayout->addWidget(zoomView);
-    bottomLayout->addWidget(color);
-    bottomLayout->addWidget(HFRReport);
-    bottomLayout->addWidget(HFRReportBox);
-    bottomLayout->addWidget(new QLabel(", "));
-    bottomLayout->addWidget(showPeakValues);
-    bottomLayout->addWidget(peakValue);
-    bottomLayout->addWidget(showScaling);
-
-    verticalSelector = new QSlider(Qt::Horizontal, this);
-    verticalSelector->setToolTip("Selects the Vertical Value");
-    verticalSelector->setVisible(false);
-    horizontalSelector = new QSlider(Qt::Horizontal, this);
-    horizontalSelector->setToolTip("Selects the Horizontal Value");
-    horizontalSelector->setVisible(false);
-    exploreMode = new QCheckBox(this);
-    exploreMode->setText("Explore Mode");
-    exploreMode->setToolTip("Zooms automatically as the sliders change");
-    exploreMode->setChecked(true);
-    exploreMode->setVisible(false);
-    mainLayout->addWidget(verticalSelector);
-    mainLayout->addWidget(horizontalSelector);
-    mainLayout->addWidget(exploreMode);
+    bottomControlLayout->addWidget(exploreMode);
+    bottomControlLayout->addWidget(barSpacing);
+    bottomControlLayout->addWidget(color);
+    bottomControlLayout->addWidget(pixelReport);
 
     QObject::connect(selectionType,  SIGNAL(currentIndexChanged(int)),
                      this, SLOT(changeSelectionType(int)));
@@ -236,6 +291,8 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
                      this, SLOT(zoomViewTo(int)));
     QObject::connect(sliceB,  &QPushButton::pressed,
                      this, &StarProfileViewer::toggleSlice);
+    QObject::connect(showCoordinates,  &QCheckBox::toggled,
+                     this, &StarProfileViewer::updateHFRandPeakSelection);
     QObject::connect(HFRReport,  &QCheckBox::toggled,
                      this, &StarProfileViewer::updateHFRandPeakSelection);
     QObject::connect(showPeakValues,  &QCheckBox::toggled,
@@ -259,15 +316,15 @@ StarProfileViewer::StarProfileViewer(QWidget *parent) : QDialog(parent)
     QObject::connect(horizontalSelector,  &QSlider::valueChanged,
                      this, &StarProfileViewer::changeSelection);
     QObject::connect(selectorsVisible,  &QCheckBox::toggled,
-                     horizontalSelector, &QWidget::setVisible);
+                     bottomSliderWidget, &QWidget::setVisible);
     QObject::connect(selectorsVisible,  &QCheckBox::toggled,
-                     verticalSelector, &QWidget::setVisible);
-    QObject::connect(selectorsVisible,  &QCheckBox::toggled,
-                     exploreMode, &QWidget::setVisible);
+                     bottomControlsWidget, &QWidget::setVisible);
     QObject::connect(toggleEnableCutoff,  &QCheckBox::toggled,
                      this, &StarProfileViewer::toggleCutoffEnabled);
     QObject::connect(m_3DPixelSeries,  &QBar3DSeries::selectedBarChanged,
                      this, &StarProfileViewer::updateSelectorBars);
+    QObject::connect(barSpacing,  &QSlider::valueChanged,
+                     this, &StarProfileViewer::updateBarSpacing);
 
     m_graph->activeTheme()->setType(Q3DTheme::Theme(3)); //Stone Moss
 
@@ -429,8 +486,23 @@ void StarProfileViewer::updateScale()
                      this, &StarProfileViewer::updateDisplayData);
 }
 
+void StarProfileViewer::updateBarSpacing(int value)
+{
+    float spacing = (float)value/100.0;
+    m_graph->setBarSpacing(QSizeF(spacing, spacing));
+}
+
 void StarProfileViewer::zoomViewTo(int where)
 {
+    if(where > 6) //One of the star centers
+    {
+        int star = where - 7;
+        int x = starCenters[star]->x - subFrame.x();
+        int y = subFrame.height() - (starCenters[star]->y - subFrame.y());
+        m_graph->primarySeries()->setSelectedBar(QPoint( y , x )); //Note row, column    y, x
+        where = 6; //This is so it will zoom to the target.
+    }
+
     switch (where) {
     case 0: //Zoom To
         break;
@@ -503,6 +575,7 @@ void StarProfileViewer::zoomViewTo(int where)
 
 
     default:
+        zoomView->setCurrentIndex(0);
         break;
     }
 }
@@ -533,12 +606,27 @@ void StarProfileViewer::changeSelectionType(int type)
 
 void StarProfileViewer::changeSelection()
 {
-    //Note row, column    y, x
-    m_graph->primarySeries()->setSelectedBar(QPoint( verticalSelector->value(), horizontalSelector->value()));
+    int x = horizontalSelector->value();
+    int y = verticalSelector->value();
+    m_graph->primarySeries()->setSelectedBar(QPoint( y , x )); //Note row, column    y, x
     if(exploreMode->isChecked())
         zoomViewTo(6); //Zoom to SelectedItem
+    updatePixelReport();
 }
 
+void StarProfileViewer::updatePixelReport()
+{
+    int x = horizontalSelector->value();
+    int y = verticalSelector->value();
+    //They need to be shifted to the location of the subframe
+    x += subFrame.x();
+    y = (subFrame.height() - 1 - y) + subFrame.y(); //Note: Y is in reverse order on the graph.
+    float barValue = getImageDataValue(x, y);
+    pixelReport->setText("Selected Pixel: (" + QString::number(x + 1) + "," + QString::number(y + 1) + "): " + QString::number(barValue, 'f', 2)); //Have to add 1 because humans start counting at 1
+
+}
+
+
 void StarProfileViewer::updateSelectorBars(QPoint position)
 {
     //Note that we need to disconnect and then reconnect to avoid triggering changeSelection
@@ -550,6 +638,7 @@ void StarProfileViewer::updateSelectorBars(QPoint position)
     //Note row, column    y, x
     verticalSelector->setValue(position.x());
     horizontalSelector->setValue(position.y());
+    updatePixelReport();
 
     QObject::connect(verticalSelector,  &QSlider::valueChanged,
                      this, &StarProfileViewer::changeSelection);
@@ -708,42 +797,56 @@ void StarProfileViewer::updateHFRandPeakSelection()
 {
     m_graph->removeCustomItems();
 
-    HFRReportBox->setText("");
-    peakValue->setText("");
+    reportBox->setText("");
+    QString reportString = "";
 
-    if(HFRReport->isChecked() || showPeakValues->isChecked())
+    //Removes all the stars from the combo box.
+    while(zoomView->count() > 7)
+        zoomView->removeItem(7);
+
+    for (int i = 0; i < starCenters.count(); i++)
     {
-
-        for (int i = 0; i < starCenters.count(); i++)
-        {
-            int x = starCenters[i]->x;
-            int row = x - subFrame.x();
-            int y = starCenters[i]->y;
-            int col = subFrame.height() - (y - subFrame.y());
-            if(subFrame.contains(x,y)){
-               double newHFR = imageData->getHFR(x,y);
-               int value = getImageDataValue(x, y);
-               QCustom3DLabel *label = new QCustom3DLabel();
-               label->setFacingCamera(true);
-               QString labelString = "";
-               if(HFRReport->isChecked())
-               {
-                   labelString = labelString + "HFR: " + QString::number(newHFR, 'f', 2) + "  ";
-                   HFRReportBox->setText(QString::number(newHFR, 'f', 2));
-               }
-               if(showPeakValues->isChecked())
-               {
-                   labelString = labelString + "Peak: " + QString::number(value);
-                   peakValue->setText(QString::number(value));
-
-               }
-               label->setText(labelString);
-               label->setPosition(QVector3D(row, value, col));
-               label->setScaling(QVector3D(1.0f, 1.0f, 1.0f));
-               m_graph->addCustomItem(label);
+        int x = starCenters[i]->x;
+        int row = x - subFrame.x();
+        int y = starCenters[i]->y;
+        int col = subFrame.height() - (y - subFrame.y());
+        if(subFrame.contains(x,y)){
+            double newHFR = imageData->getHFR(x,y);
+            int value = getImageDataValue(x, y);
+            QCustom3DLabel *label = new QCustom3DLabel();
+            label->setFacingCamera(true);
+            QString labelString = "Star " + QString::number(i + 1) + ": ";
+            if(showCoordinates->isChecked())
+            {
+                labelString = labelString + "(" + QString::number(x + 1) + ",  "+ QString::number(y + 1) + ") ";
             }
+            if(HFRReport->isChecked())
+            {
+                labelString = labelString + "HFR: " + QString::number(newHFR, 'f', 2) + "  ";
+            }
+            if(showPeakValues->isChecked())
+            {
+                labelString = labelString + "Peak: " + QString::number(value);
+
+            }
+            if(showCoordinates->isChecked() || HFRReport->isChecked() || showPeakValues->isChecked())
+            {
+                if(reportString != "")
+                    reportString += "\n";
+                reportString += labelString;
+                label->setText(labelString);
+                label->setPosition(QVector3D(row, value, col));
+                label->setScaling(QVector3D(1.0f, 1.0f, 1.0f));
+                m_graph->addCustomItem(label);
+            }
+            //Adds this star to the combo box.
+            zoomView->addItem("Star " + QString::number(i + 1));
         }
     }
+    if(reportString != "")
+    {
+        reportBox->setText(reportString);
+    }
 }
 
 void StarProfileViewer::updateColor(int selection)
