@@ -69,6 +69,7 @@ public slots:
     void zoomViewTo(int where);
     void updateSampleSize(const QString &text);
     void updateColor(int selection);
+    void updateBarSpacing(int value);
 
 
 signals:
@@ -86,16 +87,18 @@ private:
     float getImageDataValue(int x, int y);
     void getSubFrameMinMax(float *subFrameMin, float *subFrameMax, double *dataMin, double *dataMax);
 
-    QCheckBox *HFRReport;
-    QLabel *HFRReportBox;
-    QCheckBox *showPeakValues;
+    QPushButton *HFRReport;
+    QLabel *reportBox;
+    QPushButton *showPeakValues;
+    QPushButton *showCoordinates;
     QCheckBox *autoScale;
-    QCheckBox *showScaling;
+    QPushButton *showScaling;
     QComboBox *sampleSize;
     QComboBox *selectionType;
     QComboBox *zoomView;
-    QCheckBox *exploreMode;
-    QLabel *peakValue;
+    QComboBox *selectStar;
+    QPushButton *exploreMode;
+    QLabel *pixelReport;
     QLabel *maxValue;
     QLabel *minValue;
     QLabel *cutoffValue;
@@ -114,6 +117,7 @@ private:
 
     int convertToSliderValue(float value);
     float convertFromSliderValue(int value);
+    void updatePixelReport();
 
 };
 
