@@ -872,6 +872,18 @@ void CCD::registerProperty(INDI::Property *prop)
                 transferFormat = FORMAT_FITS;
         }
     }
+    else if (!strcmp(prop->getName(), "CCD_EXPOSURE_LOOP"))
+    {
+        ISwitchVectorProperty *sp = prop->getSwitch();
+        if (sp)
+        {
+            ISwitch *looping = IUFindSwitch(sp, "LOOP_ON");
+            if (looping && looping->s == ISS_ON)
+                IsLooping = true;
+            else
+                IsLooping = false;
+        }
+    }
     else if (!strcmp(prop->getName(), "TELESCOPE_TYPE"))
     {
         ISwitchVectorProperty *sp = prop->getSwitch();
@@ -1081,6 +1093,14 @@ void CCD::processSwitch(ISwitchVectorProperty *svp)
         else
             telescopeType = TELESCOPE_GUIDE;
     }
+    else if (!strcmp(svp->name, "CCD_EXPOSURE_LOOP"))
+    {
+        ISwitch *looping = IUFindSwitch(svp, "LOOP_ON");
+        if (looping && looping->s == ISS_ON)
+            IsLooping = true;
+         else
+            IsLooping = false;
+    }
     else if (!strcmp(svp->name, "CONNECTION"))
     {
         ISwitch *dSwitch = IUFindSwitch(svp, "DISCONNECT");
@@ -1597,11 +1617,27 @@ void CCD::addFITSKeywords(const QString& filename)
 
         fitsfile *fptr = nullptr;
 
+#if 0
         if (fits_open_image(&fptr, filename.toLatin1(), READWRITE, &status))
         {
             fits_report_error(stderr, status);
             return;
         }
+#endif
+
+        // Use open diskfile as it does not use extended file names which has problems opening
+        // files with [ ] or ( ) in their names.
+        if (fits_open_diskfile(&fptr, filename.toLatin1(), READONLY, &status))
+        {
+            fits_report_error(stderr, status);
+            return;
+        }
+
+        if (fits_movabs_hdu(fptr, 1, IMAGE_HDU, &status))
+        {
+            fits_report_error(stderr, status);
+            return;
+        }
 
         if (fits_update_key_str(fptr, "FILTER", filter.toLatin1().data(), key_comment.toLatin1().data(), &status))
         {
@@ -2301,4 +2337,34 @@ bool CCD::setBLOBEnabled(bool enable)
     return true;
 }
 
+bool CCD::setExposureLoopingEnabled(bool enable)
+{
+    // Set value immediately
+    IsLooping = enable;
+
+    ISwitchVectorProperty *svp = baseDevice->getSwitch("CCD_EXPOSURE_LOOP");
+
+    if (svp == nullptr)
+        return false;
+
+    svp->sp[0].s = enable ? ISS_ON : ISS_OFF;
+    svp->sp[1].s = enable ? ISS_OFF : ISS_ON;
+    clientManager->sendNewSwitch(svp);
+
+    return true;
+}
+
+bool CCD::setExposureLoopCount(uint32_t count)
+{
+    INumberVectorProperty *nvp = baseDevice->getNumber("CCD_EXPOSURE_LOOP_COUNT");
+
+    if (nvp == nullptr)
+        return false;
+
+    nvp->np[0].value = count;
+
+    clientManager->sendNewNumber(nvp);
+
+    return true;
+}
 }
