@@ -215,7 +215,8 @@ void GenericDevice::processNumber(INumberVectorProperty *nvp)
         if (geo->name() != i18n("GPS Location"))
         {
             double TZ = geo->TZ();
-            geo = new GeoLocation(lng, lat, i18n("GPS Location"), "", "", TZ, new TimeZoneRule(), elev);
+            TimeZoneRule *rule = geo->tzrule();
+            geo = new GeoLocation(lng, lat, i18n("GPS Location"), "", "", TZ, rule, elev);
         }
         else
         {
@@ -223,7 +224,7 @@ void GenericDevice::processNumber(INumberVectorProperty *nvp)
             geo->setLat(lat);
         }
 
-        qCInfo(KSTARS_INDI) << "Setting location from device. Longitude:" << lng.toDMSString() << "Latitude:" << lat.toDMSString();
+        qCInfo(KSTARS_INDI) << "Setting location from device:" << getDeviceName() << "Longitude:" << lng.toDMSString() << "Latitude:" << lat.toDMSString();
 
         KStars::Instance()->data()->setLocation(*geo);
     }
@@ -277,6 +278,8 @@ void GenericDevice::processText(ITextVectorProperty *tvp)
 
         sscanf(tp->text, "%f", &utcOffset);
 
+        qCInfo(KSTARS_INDI) << "Setting UTC time from device:" << getDeviceName() << indiDateTime.toString();
+
         KStars::Instance()->data()->changeDateTime(indiDateTime);
         KStars::Instance()->data()->syncLST();
 
