@@ -27,6 +27,7 @@
 #include "Options.h"
 #include "starobject.h"
 #include "skycomponents/skylabeler.h"
+#include "skymap.h"
 
 QString SkyObject::emptyString;
 QString SkyObject::unnamedString       = QString(I18N_NOOP("unnamed"));
@@ -552,3 +553,9 @@ SkyObject::UID SkyObject::getUID() const
 {
     return invalidUID;
 }
+
+// as inline
+bool SkyObject::isFocused()
+{
+    return SkyMap::Instance()->focusObject() == this;
+}
